# scDiffEq Analyses

Notebooks, figures, files, and helper functions to reproduce the analyses presented in the scDiffEq manuscript.

## Overview

```shell
scDiffEq/scdiffeq-analyses/
├── manuscript/
│   ├── figure_1/
│   ├── figure_2/
│   │   ├── figure_files/
│   │   ├── notebooks/
│   │   └── results/
│   ├── figure_3/
│   ...
│   ├── models/
│   └── supplementary_tables/
│
└── scdiffeq_analyses/
```

### Manuscript reproducibility

**Notebooks, scripts, and other code to reproduce and/or use**:
* Main figures
* Supplementary figures
* Supplementary tables
* Trained model checkpoints

### Code and helper functions

These are contained in `scdiffeq_analyses/`

### Installation

```bash
git clone https://github.com/scDiffEq/scdiffeq-analyses.git;
cd scdiffeq-analyses; pip install -e .
```

